Struct Cfgr
#[repr(transparent)]pub struct Cfgr(pub u32);Expand description
configuration register 1
Tuple Fields
0: u32Implementations
impl Cfgr
impl Cfgr
pub const fn set_dmacfg(&mut self, val: Dmacfg)
pub const fn set_dmacfg(&mut self, val: Dmacfg)
Direct memory access configuration
pub const fn set_extsel(&mut self, val: u8)
pub const fn set_extsel(&mut self, val: u8)
external trigger selection for regular group
pub const fn exten(&self) -> Exten
pub const fn exten(&self) -> Exten
external trigger enable and polarity selection for regular channels
pub const fn set_exten(&mut self, val: Exten)
pub const fn set_exten(&mut self, val: Exten)
external trigger enable and polarity selection for regular channels
pub const fn set_ovrmod(&mut self, val: Ovrmod)
pub const fn set_ovrmod(&mut self, val: Ovrmod)
overrun mode
pub const fn set_autdly(&mut self, val: bool)
pub const fn set_autdly(&mut self, val: bool)
delayed conversion mode
pub const fn set_discen(&mut self, val: bool)
pub const fn set_discen(&mut self, val: bool)
discontinuous mode for regular channels
pub const fn set_discnum(&mut self, val: u8)
pub const fn set_discnum(&mut self, val: u8)
discontinuous mode channel count
pub const fn set_jdiscen(&mut self, val: bool)
pub const fn set_jdiscen(&mut self, val: bool)
discontinuous mode on injected channels
pub const fn set_awd1sgl(&mut self, val: Awd1sgl)
pub const fn set_awd1sgl(&mut self, val: Awd1sgl)
enable the watchdog 1 on a single channel or on all channels
pub const fn set_awd1en(&mut self, val: bool)
pub const fn set_awd1en(&mut self, val: bool)
analog watchdog 1 enable on regular channels
pub const fn set_jawd1en(&mut self, val: bool)
pub const fn set_jawd1en(&mut self, val: bool)
analog watchdog 1 enable on injected channels
pub const fn set_awd1ch(&mut self, val: u8)
pub const fn set_awd1ch(&mut self, val: u8)
analog watchdog 1 channel selection